# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conint
from access_server_connector.models.access_mode import AccessMode
from access_server_connector.models.binding import Binding
from access_server_connector.models.resource_type import ResourceType

class PackageRuleIn(BaseModel):
    """
    PackageRuleIn
    """
    access_mode: Optional[AccessMode] = None
    unlock_delay_ms: Optional[conint(strict=True, ge=0)] = 0
    unlock_align_cron: Optional[StrictStr] = None
    access_duration_ms: Optional[conint(strict=True, gt=0)] = None
    starts_at: Optional[StrictInt] = None
    ends_at: Optional[StrictInt] = None
    window_cron: Optional[StrictStr] = None
    window_duration_ms: Optional[conint(strict=True, gt=0)] = None
    timezone: Optional[StrictStr] = None
    binding: Optional[Binding] = None
    resource_type: ResourceType = Field(...)
    resource_id: StrictInt = Field(...)
    expired_message: Optional[StrictStr] = None
    __properties = ["access_mode", "unlock_delay_ms", "unlock_align_cron", "access_duration_ms", "starts_at", "ends_at", "window_cron", "window_duration_ms", "timezone", "binding", "resource_type", "resource_id", "expired_message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PackageRuleIn:
        """Create an instance of PackageRuleIn from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if unlock_align_cron (nullable) is None
        # and __fields_set__ contains the field
        if self.unlock_align_cron is None and "unlock_align_cron" in self.__fields_set__:
            _dict['unlock_align_cron'] = None

        # set to None if access_duration_ms (nullable) is None
        # and __fields_set__ contains the field
        if self.access_duration_ms is None and "access_duration_ms" in self.__fields_set__:
            _dict['access_duration_ms'] = None

        # set to None if starts_at (nullable) is None
        # and __fields_set__ contains the field
        if self.starts_at is None and "starts_at" in self.__fields_set__:
            _dict['starts_at'] = None

        # set to None if ends_at (nullable) is None
        # and __fields_set__ contains the field
        if self.ends_at is None and "ends_at" in self.__fields_set__:
            _dict['ends_at'] = None

        # set to None if window_cron (nullable) is None
        # and __fields_set__ contains the field
        if self.window_cron is None and "window_cron" in self.__fields_set__:
            _dict['window_cron'] = None

        # set to None if window_duration_ms (nullable) is None
        # and __fields_set__ contains the field
        if self.window_duration_ms is None and "window_duration_ms" in self.__fields_set__:
            _dict['window_duration_ms'] = None

        # set to None if timezone (nullable) is None
        # and __fields_set__ contains the field
        if self.timezone is None and "timezone" in self.__fields_set__:
            _dict['timezone'] = None

        # set to None if expired_message (nullable) is None
        # and __fields_set__ contains the field
        if self.expired_message is None and "expired_message" in self.__fields_set__:
            _dict['expired_message'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PackageRuleIn:
        """Create an instance of PackageRuleIn from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PackageRuleIn.parse_obj(obj)

        _obj = PackageRuleIn.parse_obj({
            "access_mode": obj.get("access_mode"),
            "unlock_delay_ms": obj.get("unlock_delay_ms") if obj.get("unlock_delay_ms") is not None else 0,
            "unlock_align_cron": obj.get("unlock_align_cron"),
            "access_duration_ms": obj.get("access_duration_ms"),
            "starts_at": obj.get("starts_at"),
            "ends_at": obj.get("ends_at"),
            "window_cron": obj.get("window_cron"),
            "window_duration_ms": obj.get("window_duration_ms"),
            "timezone": obj.get("timezone"),
            "binding": obj.get("binding"),
            "resource_type": obj.get("resource_type"),
            "resource_id": obj.get("resource_id"),
            "expired_message": obj.get("expired_message")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, List
from pydantic import BaseModel, Field, conlist
from access_server_connector.models.rule_preset_out import RulePresetOut

class RulePresetListOut(BaseModel):
    """
    All of a portal's presets, flat and grouped for the editor.  ``presets_by_type`` partitions them: each ResourceType key plus an ``any`` bucket for type-agnostic presets. When offering presets for an event, the editor shows ``presets_by_type[event] + presets_by_type[any]``.  # noqa: E501
    """
    presets: conlist(RulePresetOut) = Field(...)
    presets_by_type: Dict[str, conlist(RulePresetOut)] = Field(...)
    __properties = ["presets", "presets_by_type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RulePresetListOut:
        """Create an instance of RulePresetListOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in presets (list)
        _items = []
        if self.presets:
            for _item in self.presets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['presets'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in presets_by_type (dict of array)
        _field_dict_of_array = {}
        if self.presets_by_type:
            for _key in self.presets_by_type:
                if self.presets_by_type[_key] is not None:
                    _field_dict_of_array[_key] = [
                        _item.to_dict() for _item in self.presets_by_type[_key]
                    ]
            _dict['presets_by_type'] = _field_dict_of_array
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RulePresetListOut:
        """Create an instance of RulePresetListOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RulePresetListOut.parse_obj(obj)

        _obj = RulePresetListOut.parse_obj({
            "presets": [RulePresetOut.from_dict(_item) for _item in obj.get("presets")] if obj.get("presets") is not None else None,
            "presets_by_type": {
                _k: [RulePresetOut.from_dict(_item) for _item in _v] if _v is not None else None
                for _k, _v in obj["presets_by_type"].items()
            }
            if obj.get("presets_by_type") is not None
            else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictBool, StrictInt, conlist
from access_server_connector.models.member_ownership_out import MemberOwnershipOut

class PackageMemberOut(BaseModel):
    """
    One member of a package with ALL their ownership reasons — the deduped roster.  A member holding the package via several grants (rebuy, manual + order, …) appears once, with every grant nested; the ledger view (…/ownerships) shows them per grant.  # noqa: E501
    """
    member_id: StrictInt = Field(...)
    is_effective: StrictBool = Field(...)
    ownerships: conlist(MemberOwnershipOut) = Field(...)
    __properties = ["member_id", "is_effective", "ownerships"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PackageMemberOut:
        """Create an instance of PackageMemberOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in ownerships (list)
        _items = []
        if self.ownerships:
            for _item in self.ownerships:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ownerships'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PackageMemberOut:
        """Create an instance of PackageMemberOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PackageMemberOut.parse_obj(obj)

        _obj = PackageMemberOut.parse_obj({
            "member_id": obj.get("member_id"),
            "is_effective": obj.get("is_effective"),
            "ownerships": [MemberOwnershipOut.from_dict(_item) for _item in obj.get("ownerships")] if obj.get("ownerships") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.rule_preset_list_out import RulePresetListOut  # noqa: E501

class TestRulePresetListOut(unittest.TestCase):
    """RulePresetListOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RulePresetListOut:
        """Test RulePresetListOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RulePresetListOut`
        """
        model = RulePresetListOut()  # noqa: E501
        if include_optional:
            return RulePresetListOut(
                presets = [
                    access_server_connector.models.rule_preset_out.RulePresetOut(
                        id = 56, 
                        name = '', 
                        resource_type = null, 
                        access_mode = 'available', 
                        unlock_delay_ms = 56, 
                        unlock_align_cron = '', 
                        access_duration_ms = 56, 
                        starts_at = 56, 
                        ends_at = 56, 
                        window_cron = '', 
                        window_duration_ms = 56, 
                        timezone = '', 
                        binding = 'single', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
                presets_by_type = {
                    'key' : [
                        access_server_connector.models.rule_preset_out.RulePresetOut(
                            id = 56, 
                            name = '', 
                            resource_type = null, 
                            access_mode = 'available', 
                            unlock_delay_ms = 56, 
                            unlock_align_cron = '', 
                            access_duration_ms = 56, 
                            starts_at = 56, 
                            ends_at = 56, 
                            window_cron = '', 
                            window_duration_ms = 56, 
                            timezone = '', 
                            binding = 'single', 
                            expired_message = '', 
                            created_at = 56, 
                            updated_at = 56, )
                        ]
                    }
            )
        else:
            return RulePresetListOut(
                presets = [
                    access_server_connector.models.rule_preset_out.RulePresetOut(
                        id = 56, 
                        name = '', 
                        resource_type = null, 
                        access_mode = 'available', 
                        unlock_delay_ms = 56, 
                        unlock_align_cron = '', 
                        access_duration_ms = 56, 
                        starts_at = 56, 
                        ends_at = 56, 
                        window_cron = '', 
                        window_duration_ms = 56, 
                        timezone = '', 
                        binding = 'single', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
                presets_by_type = {
                    'key' : [
                        access_server_connector.models.rule_preset_out.RulePresetOut(
                            id = 56, 
                            name = '', 
                            resource_type = null, 
                            access_mode = 'available', 
                            unlock_delay_ms = 56, 
                            unlock_align_cron = '', 
                            access_duration_ms = 56, 
                            starts_at = 56, 
                            ends_at = 56, 
                            window_cron = '', 
                            window_duration_ms = 56, 
                            timezone = '', 
                            binding = 'single', 
                            expired_message = '', 
                            created_at = 56, 
                            updated_at = 56, )
                        ]
                    },
        )
        """

    def testRulePresetListOut(self):
        """Test RulePresetListOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.package_member_out import PackageMemberOut  # noqa: E501

class TestPackageMemberOut(unittest.TestCase):
    """PackageMemberOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PackageMemberOut:
        """Test PackageMemberOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PackageMemberOut`
        """
        model = PackageMemberOut()  # noqa: E501
        if include_optional:
            return PackageMemberOut(
                member_id = 56,
                is_effective = True,
                ownerships = [
                    access_server_connector.models.member_ownership_out.MemberOwnershipOut(
                        member_id = 56, 
                        reason_id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        is_effective = True, 
                        granted_at = 56, 
                        is_test = True, 
                        period_end = 56, 
                        grace_until = 56, )
                    ]
            )
        else:
            return PackageMemberOut(
                member_id = 56,
                is_effective = True,
                ownerships = [
                    access_server_connector.models.member_ownership_out.MemberOwnershipOut(
                        member_id = 56, 
                        reason_id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        is_effective = True, 
                        granted_at = 56, 
                        is_test = True, 
                        period_end = 56, 
                        grace_until = 56, )
                    ],
        )
        """

    def testPackageMemberOut(self):
        """Test PackageMemberOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.rule_presets_api import RulePresetsApi  # noqa: E501


class TestRulePresetsApi(unittest.IsolatedAsyncioTestCase):
    """RulePresetsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = RulePresetsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_v1_rule_presets_post(self) -> None:
        """Test case for create_v1_rule_presets_post

        Create a reusable rule preset  # noqa: E501
        """
        pass

    async def test_delete_preset_v1_rule_presets_preset_id_delete(self) -> None:
        """Test case for delete_preset_v1_rule_presets_preset_id_delete

        Delete a rule preset  # noqa: E501
        """
        pass

    async def test_get_preset_v1_rule_presets_preset_id_get(self) -> None:
        """Test case for get_preset_v1_rule_presets_preset_id_get

        Get one rule preset  # noqa: E501
        """
        pass

    async def test_list_presets_v1_rule_presets_get(self) -> None:
        """Test case for list_presets_v1_rule_presets_get

        List the portal's rule presets (flat + grouped per resource type)  # noqa: E501
        """
        pass

    async def test_update_preset_v1_rule_presets_preset_id_patch(self) -> None:
        """Test case for update_preset_v1_rule_presets_preset_id_patch

        Edit a rule preset (name / type hint / body)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
